// -*- C++ -*-
/*!
 * @file  BirdsEyeComposer.h
 * @brief 8枚の画像から1枚の俯瞰画像へ合成を行う
 * @date  $Date$
 *
 * @author 株式会社 東日本計算センター
 *
 * $Id$
 */

#ifndef BIRDSEYECOMPOSER_H
#define BIRDSEYECOMPOSER_H

#include <rtm/idl/BasicDataTypeSkel.h>
#include <rtm/idl/ExtendedDataTypesSkel.h>
#include <rtm/idl/InterfaceDataTypesSkel.h>
//add
#include "local_basic_type.h"
#include "NM33BirdsEyeSystem.h"

//Opencv関連のインクルード宣言
#include <opencv2/opencv.hpp>

// Service implementation headers
// <rtc-template block="service_impl_h">
#include "BirdsEyeControlSVC_impl.h"

// </rtc-template>

// Service Consumer stub headers
// <rtc-template block="consumer_stub_h">

// </rtc-template>

// Service Consumer stub headers
// <rtc-template block="port_stub_h">
// </rtc-template>

using namespace RTC;

#include <rtm/Manager.h>
#include <rtm/DataFlowComponentBase.h>
#include <rtm/CorbaPort.h>
#include <rtm/DataInPort.h>
#include <rtm/DataOutPort.h>

/*====================================================
	マクロ定義
 ===================================================*/
//マトリクス用
#define CAPTURE_NOACTION	(0)		//何もしない
#define CAPTURE_ONCE		(1)		//一回キャプチャする
#define CAPTURE_CYCLE		(2)		//周期的にキャプチャする
#define CAPTURE_STOP		(3)		//周期的なキャプチャを停止する

//メッセージ用
#define MES_BIRDS_EYE_COMPOSE_ERROR			"[ERROR MESSEGE]Birds Eye Compose Error!!"			//俯瞰画像合成に失敗しました
#define MES_BIRDS_EYE_INPUT_DATA_NON		"[MESSEGE]No Input Image Data!!"					//入力画像データがありません
#define MES_BIRDS_EYE_JPG_FILE_CREATE_ERROR	"[ERROR MESSEGE]Birds Eye File Create Error!!"		//俯瞰画像のJPGファイル生成に失敗しました
#define MES_BIRDS_EYE_FOLDER_CREATE_ERROR	"[ERROR MESSEGE]Folder Create Error!!"				//フォルダの生成に失敗しました
#define MES_BIRDS_EYE_CONFIG_ERROR			"[ERROR MESSEGE]Configuration Set Error!!"			//コンフィギュレーションの設定に異常値を設定しています
#define MES_RECOVERY_RESET_RETRY_CNT		"[MESSEGE]Recovery Reset Retry Count = "			//リカバリリセットのRetry回数はXX

//コンフィギュレーション用
#define ANGLE_MIN			(-360)	//角度調整MIN値
#define ANGLE_MAX			(360)	//角度調整MAX値

#define HORIZONTAL_X_MIN	(0)		//横配置の時のX軸調整座標MIN値
#define HORIZONTAL_X_MAX	(257)	//横配置の時のX軸調整座標MAX値
#define HORIZONTAL_Y_MIN	(0)		//横配置の時のY軸調整座標MIN値
#define HORIZONTAL_Y_MAX	(400)	//横配置の時のY軸調整座標MAX値

#define VERTICAL_X_MIN		(0)		//縦配置の時のX軸調整座標MIN値
#define VERTICAL_X_MAX		(337)	//縦配置の時のX軸調整座標MAX値
#define VERTICAL_Y_MIN		(0)		//縦配置の時のY軸調整座標MIN値
#define VERTICAL_Y_MAX		(320)	//縦配置の時のY軸調整座標MAX値

#define DISPLAY_OFF			"Off"	//個別非表示設定
#define DISPLAY_ON			"On"	//個別表示設定


/*!
 * @class BirdsEyeComposer
 * @brief 8枚の画像から1枚の俯瞰画像へ合成を行う
 *
 * 別紙"機能仕様書_俯瞰画像合成RTC"参照
 *
 * 別紙"機能仕様書_俯瞰画像合成RTC"参照
 *
 * 別紙"機能仕様書_俯瞰画像合成RTC"参照
 *
 * 別紙"機能仕様書_俯瞰画像合成RTC"参照
 *
 */
class BirdsEyeComposer
  : public RTC::DataFlowComponentBase
{
 public:
  /*!
   * @brief constructor
   * @param manager Maneger Object
   */
  BirdsEyeComposer(RTC::Manager* manager);

  /*!
   * @brief destructor
   */
  ~BirdsEyeComposer();

  // <rtc-template block="public_attribute">
  
  // </rtc-template>

  // <rtc-template block="public_operation">
  
  // </rtc-template>

  /***
   * 俯瞰画像合成RTCの初期化処理
   *
   * The initialize action (on CREATED->ALIVE transition)
   * formaer rtc_init_entry() 
   *
   * @return RTC::ReturnCode_t
   * 
   * @pre -
   * @post -
   * 
   */
   virtual RTC::ReturnCode_t onInitialize();

  /***
   * 俯瞰画像合成RTCの終了処理
   *
   * The finalize action (on ALIVE->END transition)
   * formaer rtc_exiting_entry()
   *
   * @return RTC::ReturnCode_t
   * 
   * @pre -
   * @post -
   * 
   */
   virtual RTC::ReturnCode_t onFinalize();

  /***
   *
   * The startup action when ExecutionContext startup
   * former rtc_starting_entry()
   *
   * @param ec_id target ExecutionContext Id
   *
   * @return RTC::ReturnCode_t
   * 
   * 
   */
  // virtual RTC::ReturnCode_t onStartup(RTC::UniqueId ec_id);

  /***
   *
   * The shutdown action when ExecutionContext stop
   * former rtc_stopping_entry()
   *
   * @param ec_id target ExecutionContext Id
   *
   * @return RTC::ReturnCode_t
   * 
   * 
   */
  // virtual RTC::ReturnCode_t onShutdown(RTC::UniqueId ec_id);

  /***
   * 俯瞰画像合成RTCの開始処理
   *
   * The activated action (Active state entry action)
   * former rtc_active_entry()
   *
   * @param ec_id target ExecutionContext Id
   *
   * @return RTC::ReturnCode_t
   * 
   * @pre -
   * @post -
   * 
   */
   virtual RTC::ReturnCode_t onActivated(RTC::UniqueId ec_id);

  /***
   * 俯瞰画像合成RTCの停止処理
   *
   * The deactivated action (Active state exit action)
   * former rtc_active_exit()
   *
   * @param ec_id target ExecutionContext Id
   *
   * @return RTC::ReturnCode_t
   * 
   * @pre -
   * @post -
   * 
   */
   virtual RTC::ReturnCode_t onDeactivated(RTC::UniqueId ec_id);

  /***
   * 俯瞰画像合成を行う周期処理
   *
   * The execution action that is invoked periodically
   * former rtc_active_do()
   *
   * @param ec_id target ExecutionContext Id
   *
   * @return RTC::ReturnCode_t
   * 
   * @pre 合成モードに"俯瞰画像合成許可"が設定されていること
   * MultiCameraImage型の入力があること
   * @post -
   * 
   */
   virtual RTC::ReturnCode_t onExecute(RTC::UniqueId ec_id);

  /***
   * 俯瞰画像合成RTCのエラー遷移処理
   *
   * The aborting action when main logic error occurred.
   * former rtc_aborting_entry()
   *
   * @param ec_id target ExecutionContext Id
   *
   * @return RTC::ReturnCode_t
   * 
   * 
   */
   virtual RTC::ReturnCode_t onAborting(RTC::UniqueId ec_id);

  /***
   * 俯瞰画像合成RTCのエラー処理
   *
   * The error action in ERROR state
   * former rtc_error_do()
   *
   * @param ec_id target ExecutionContext Id
   *
   * @return RTC::ReturnCode_t
   * 
   * @pre -
   * @post システムリセットすることでエラー状態から復帰する（Reset
   * へ遷移）
   * 
   */
   virtual RTC::ReturnCode_t onError(RTC::UniqueId ec_id);

  /***
   * 俯瞰画像合成RTCのReset処理
   *
   * The reset action that is invoked resetting
   * This is same but different the former rtc_init_entry()
   *
   * @param ec_id target ExecutionContext Id
   *
   * @return RTC::ReturnCode_t
   * 
   * @pre -
   * @post システムリセットすることでReset状態から復帰する（Activa
   * teへ遷移）
   * 
   */
   virtual RTC::ReturnCode_t onReset(RTC::UniqueId ec_id);
  
  /***
   *
   * The state update action that is invoked after onExecute() action
   * no corresponding operation exists in OpenRTm-aist-0.2.0
   *
   * @param ec_id target ExecutionContext Id
   *
   * @return RTC::ReturnCode_t
   * 
   * 
   */
  // virtual RTC::ReturnCode_t onStateUpdate(RTC::UniqueId ec_id);

  /***
   *
   * The action that is invoked when execution context's rate is changed
   * no corresponding operation exists in OpenRTm-aist-0.2.0
   *
   * @param ec_id target ExecutionContext Id
   *
   * @return RTC::ReturnCode_t
   * 
   * 
   */
  // virtual RTC::ReturnCode_t onRateChanged(RTC::UniqueId ec_id);


 protected:
  // <rtc-template block="protected_attribute">
  
  // </rtc-template>

  // <rtc-template block="protected_operation">
  
  // </rtc-template>

  // Configuration variable declaration
  // <rtc-template block="config_declare">
  /*!
   * 俯瞰画像合成時の画像Bの角度を調整する
   * - Name: Angle_B Angle_B
   * - DefaultValue: -24
   * - Unit: 角度
   * - Range: -360<=x<=360
   * - Constraint: -
   */
  long int m_Angle_B;
  /*!
   * 俯瞰画像合成時の画像Dの角度を調整する
   * - Name: Angle_D Angle_D
   * - DefaultValue: -158
   * - Unit: 角度
   * - Range: -360<=x<=360
   * - Constraint: -
   */
  long int m_Angle_D;
  /*!
   * 俯瞰画像合成時の画像Eの角度を調整する
   * - Name: Angle_E Angle_E
   * - DefaultValue: -180
   * - Unit: 角度
   * - Range: -360<=x<=360
   * - Constraint: -
   */
  long int m_Angle_E;
  /*!
   * 俯瞰画像合成時の画像Fの角度を調整する
   * - Name: Angle_F Angle_F
   * - DefaultValue: -202
   * - Unit: 角度
   * - Range: -360<=x<=360
   * - Constraint: -
   */
  long int m_Angle_F;
  /*!
   * 俯瞰画像合成時の画像Hの角度を調整する
   * - Name: Angle_H Angle_H
   * - DefaultValue: -340
   * - Unit: 角度
   * - Range: -360<=x<=360
   * - Constraint: -
   */
  long int m_Angle_H;
  /*!
   * A画像を配置する為のX座標を調整する
   * - Name: Coord_X_A Coord_X_A
   * - DefaultValue: 135
   * - Unit: pixel
   * - Range: 0<=x<=257
   * - Constraint: -
   */
  long int m_Coord_X_A;
  /*!
   * A画像を配置する為のY座標を調整する
   * - Name: Coord_Y_A Coord_Y_A
   * - DefaultValue: 0
   * - Unit: pixel
   * - Range: 0<=x<=400
   * - Constraint: -
   */
  long int m_Coord_Y_A;
  /*!
   * B画像を配置する為のX座標を調整する
   * - Name: Coord_X_B Coord_X_B
   * - DefaultValue: 210
   * - Unit: pixel
   * - Range: 0<=x<=257
   * - Constraint: -
   */
  long int m_Coord_X_B;
  /*!
   * B画像を配置する為のY座標を調整する
   * - Name: Coord_Y_B Coord_Y_B
   * - DefaultValue: 23
   * - Unit: pixel
   * - Range: 0<=x<=400
   * - Constraint: -
   */
  long int m_Coord_Y_B;
  /*!
   * C画像を配置する為のX座標を調整する
   * - Name: Coord_X_C Coord_X_C
   * - DefaultValue: 337
   * - Unit: pixel
   * - Range: 0<=x<=337
   * - Constraint: -
   */
  long int m_Coord_X_C;
  /*!
   * C画像を配置する為のY座標を調整する
   * - Name: Coord_Y_C Coord_Y_C
   * - DefaultValue: 160
   * - Unit: pixel
   * - Range: 0<=x<=320
   * - Constraint: -
   */
  long int m_Coord_Y_C;
  /*!
   * D画像を配置する為のX座標を調整する
   * - Name: Coord_X_D Coord_X_D
   * - DefaultValue: 202
   * - Unit: pixel
   * - Range: 0<=x<=257
   * - Constraint: -
   */
  long int m_Coord_X_D;
  /*!
   * D画像を配置する為のY座標を調整する
   * - Name: Coord_Y_D Coord_Y_D
   * - DefaultValue: 382
   * - Unit: pixel
   * - Range: 0<=x<=400
   * - Constraint: -
   */
  long int m_Coord_Y_D;
  /*!
   * E画像を配置する為のX座標を調整する
   * - Name: Coord_X_E Coord_X_E
   * - DefaultValue: 135
   * - Unit: pixel
   * - Range: 0<=x<=257
   * - Constraint: -
   */
  long int m_Coord_X_E;
  /*!
   * E画像を配置する為のY座標を調整する
   * - Name: Coord_Y_E Coord_Y_E
   * - DefaultValue: 400
   * - Unit: pixel
   * - Range: 0<=x<=400
   * - Constraint: -
   */
  long int m_Coord_Y_E;
  /*!
   * F画像を配置する為のX座標を調整する
   * - Name: Coord_X_F Coord_X_F
   * - DefaultValue: 30
   * - Unit: pixel
   * - Range: 0<=x<=257
   * - Constraint: -
   */
  long int m_Coord_X_F;
  /*!
   * F画像を配置する為のY座標を調整する
   * - Name: Coord_Y_F Coord_Y_F
   * - DefaultValue: 382
   * - Unit: pixel
   * - Range: 0<=x<=400
   * - Constraint: -
   */
  long int m_Coord_Y_F;
  /*!
   * G画像を配置する為のX座標を調整する
   * - Name: Coord_X_G Coord_X_G
   * - DefaultValue: 0
   * - Unit: pixel
   * - Range: 0<=x<=337
   * - Constraint: -
   */
  long int m_Coord_X_G;
  /*!
   * G画像を配置する為のY座標を調整する
   * - Name: Coord_Y_G Coord_Y_G
   * - DefaultValue: 160
   * - Unit: pixel
   * - Range: 0<=x<=320
   * - Constraint: -
   */
  long int m_Coord_Y_G;
  /*!
   * H画像を配置する為のX座標を調整する
   * - Name: Coord_X_H Coord_X_H
   * - DefaultValue: 35
   * - Unit: pixel
   * - Range: 0<=x<=257
   * - Constraint: -
   */
  long int m_Coord_X_H;
  /*!
   * H画像を配置する為のY座標を調整する
   * - Name: Coord_Y_H Coord_Y_H
   * - DefaultValue: 20
   * - Unit: pixel
   * - Range: 0<=x<=400
   * - Constraint: -
   */
  long int m_Coord_Y_H;
  /*!
   * A画像の表示/非表示を切り替える
   * - Name: Display_A Display_A
   * - DefaultValue: On
   * - Range: (On,Off)
   */
  std::string m_Display_A;
  /*!
   * B画像の表示/非表示を切り替える
   * - Name: Display_B Display_B
   * - DefaultValue: On
   * - Range: (On,Off)
   */
  std::string m_Display_B;
  /*!
   * C画像の表示/非表示を切り替える
   * - Name: Display_C Display_C
   * - DefaultValue: On
   * - Range: (On,Off)
   */
  std::string m_Display_C;
  /*!
   * D画像の表示/非表示を切り替える
   * - Name: Display_D Display_D
   * - DefaultValue: On
   * - Range: (On,Off)
   */
  std::string m_Display_D;
  /*!
   * E画像の表示/非表示を切り替える
   * - Name: Display_E Display_E
   * - DefaultValue: On
   * - Range: (On,Off)
   */
  std::string m_Display_E;
  /*!
   * F画像の表示/非表示を切り替える
   * - Name: Display_F Display_F
   * - DefaultValue: On
   * - Range: (On,Off)
   */
  std::string m_Display_F;
  /*!
   * G画像の表示/非表示を切り替える
   * - Name: Display_G Display_G
   * - DefaultValue: On
   * - Range: (On,Off)
   */
  std::string m_Display_G;
  /*!
   * H画像の表示/非表示を切り替える
   * - Name: Display_H Display_H
   * - DefaultValue: On
   * - Range: (On,Off)
   */
  std::string m_Display_H;

  // </rtc-template>

  // DataInPort declaration
  // <rtc-template block="inport_declare">
  RTC::MultiCameraImages m_MultiCaptureimage;
  /*!
   * カメラID =
   * 0～7の内、接続されているカメラのキャプチャ画像が入力される
   * - Type: RTC::MultiCameraImages
   * - Number: 8
   * - Semantics: -
   * - Unit: -
   * - Frequency: 1秒周期
   * - Operation Cycle: 1秒周期
   */
  InPort<RTC::MultiCameraImages> m_MultiCaptureimageIn;
  
  // </rtc-template>


  // DataOutPort declaration
  // <rtc-template block="outport_declare">
  RTC::CameraImage m_BirdsEyeimage;
  /*!
   * 合成した俯瞰画像を出力する
   * - Type: RTC::CameraImage
   * - Number: 1
   * - Semantics: -
   * - Unit: -
   * - Frequency: 1秒周期
   * - Operation Cycle: 1秒周期
   */
  OutPort<RTC::CameraImage> m_BirdsEyeimageOut;
  
  // </rtc-template>

  // CORBA Port declaration
  // <rtc-template block="corbaport_declare">
  /*!
   * 俯瞰画像合成動作を制御する
   * Interface: 合成モードや撮影モードの設定及び、キャプチャ動作要
   *            求などのI/Fを提供する
   */
  RTC::CorbaPort m_BirdsEyeControlServPort;
  /*!
   * 俯瞰画像合成RTCのシステム制御
   * Interface: リセット制御のI/Fを提供する
   */
  RTC::CorbaPort m_BirdsEyeSystemContServPort;
  
  // </rtc-template>

  // Service declaration
  // <rtc-template block="service_declare">
  /*!
   * 俯瞰画像を合成する際の合成モードの設定及び、状態を取得する
   * 　①SetBirdsEyeComposeMode　・・・　設定処理
   * 　②GetBirdsEyeComposeMode　・・・　取得処理
   * - Argument:      ①SetBirdsEyeComposeModeの引数　・・・　
   *                  　・COMPOSE_MODE_OFF：俯瞰画像合成禁止
   *                  　・COMPOSE_MODE_ON：俯瞰画像合成許可
   *                  ②GetBirdsEyeComposeModeの引数　・・・　なし
   * - Return Value:  ①SetBirdsEyeComposeModeの戻り値　・・・　な
   *                  し
   *                  ②GetBirdsEyeComposeModeの戻り値　・・・　
   *                  　・COMPOSE_MODE_OFF：俯瞰画像合成禁止
   *                  　・COMPOSE_MODE_ON：俯瞰画像合成許可
   * - Exception:     なし
   * - PreCondition:  -
   * - PostCondition: -
   */
  BirdsEyeComposeModeSVC_impl m_BirdsEyeComposeModeProv;
  /*!
   * 俯瞰画像を合成する際の撮影モードの設定及び、状態を取得する
   * 　①SetBirdsEyeCaptureMode　・・・　設定処理
   * 　②GetBirdsEyeCaptureMode　・・・　取得処理
   * - Argument:      ①SetBirdsEyeCaptureModeの引数　・・・　
   *                  　・CAPT_MODE_PICTURE：静止画
   *                  　・CAPT_MODE_VIDEO：動画
   *                  ②GetBirdsEyeCaptureModeの引数　・・・　なし
   * - Return Value:  ①SetBirdsEyeCaptureModeの戻り値　・・・　な
   *                  し
   *                  ②GetBirdsEyeCaptureModeの戻り値　・・・　
   *                  　・CAPT_MODE_PICTURE：静止画
   *                  　・CAPT_MODE_VIDEO：動画
   * - Exception:     なし
   * - PreCondition:  -
   * - PostCondition: -
   */
  BirdsEyeCaptureModeSVC_impl m_BirdsEyeCaptureModeProv;
  /*!
   * キャプチャ動作の開始/停止の要求及び、状態を取得する
   * 　①ReqBirdsEyeCaptureTrigger　・・・　設定処理
   * 　②GetBirdsEyeCaptureTrigger　・・・　取得処理
   * - Argument:      ①ReqBirdsEyeCaptureTriggerの引数　・・・　
   *                  　・CAPT_TRIG_START：開始
   *                  　・CAPT_TRIG_STOP：停止
   *                  ②GetBirdsEyeCaptureTriggerの引数　・・・　な
   *                  し
   * - Return Value:  ①ReqBirdsEyeCaptureTriggerの戻り値　・・・　
   *                  なし
   *                  ②GetBirdsEyeCaptureTriggerの戻り値　・・・　
   *                  　・CAPT_TRIG_START：開始
   *                  　・CAPT_TRIG_STOP：停止
   * - Exception:     なし
   * - PreCondition:  -
   * - PostCondition: -
   */
  BirdsEyeCaptureTriggerSVC_impl m_BirdsEyeCaptureTriggerProv;
  /*!
   * 俯瞰画像合成の進捗状況の設定及び、状態を取得する
   * 　①SetBirdsEyeProgressSts　・・・　設定処理
   * 　②GetBirdsEyeProgressSts　・・・　取得処理
   * - Argument:      ①SetBirdsEyeProgressStsの引数　・・・　
   *                  　・PROG_STS_FIN：完了
   *                  　・PROG_STS_COMPOSITE：合成中
   *                  ②GetBirdsEyeProgressStsの引数　・・・　なし
   * - Return Value:  ①SetBirdsEyeProgressStsの戻り値　・・・　な
   *                  し
   *                  ②GetBirdsEyeProgressStsの戻り値　・・・　
   *                  　・PROG_STS_FIN：完了
   *                  　・PROG_STS_COMPOSITE：合成中
   * - Exception:     なし
   * - PreCondition:  -
   * - PostCondition: -
   */
  BirdsEyeProgressSVC_impl m_BirdsEyeProgressProv;
  /*!
   * 俯瞰画像合成RTCのリセットの要求及び、状態を取得する
   * 　①ReqBirdsEyeReset　・・・　要求処理
   * 　②GetBirdsEyeReset　・・・　取得処理
   * - Argument:      ①ReqBirdsEyeResetの引数　・・・　
   *                  　・RESET_TRIG_ON：Reset On
   *                  　・RESET_TRIG_OFF：Reset Off
   *                  ②GetBirdsEyeResetの引数　・・・　なし
   * - Return Value:  ①ReqBirdsEyeResetの戻り値　・・・　なし
   *                  ②GetBirdsEyeResetの戻り値　・・・　
   *                  　・RESET_TRIG_ON：Reset On
   *                  　・RESET_TRIG_OFF：Reset Off
   * - Exception:     なし
   * - PreCondition:  -
   * - PostCondition: -
   */
  BirdsEyeResetSVC_impl m_BirdsEyeResetProv;
  
  // </rtc-template>

  // Consumer declaration
  // <rtc-template block="consumer_declare">
  
  // </rtc-template>

 private:
  // <rtc-template block="private_attribute">
  
  // </rtc-template>

  // <rtc-template block="private_operation">
  
  // </rtc-template>

  //add
  uWord_Type BirdsEyeActMatrix(uWord_Type *);	//マトリクスチェック処理
  uWord_Type MakeBirdsEyeCompose(void);			//俯瞰合成処理
  uWord_Type BirdsEyeJPGFileCreate(void);		//JPGファイル保存処理
  uWord_Type BirdsEyeConfigChk(void);			//コンフィギュレーションチェック処理
  void BirdsEyeFPSLogOut(void);					//FPSログ出力

  uWord_Type m_uWBackUpComposeMode;				//合成モードのバックアップ(変化チェック用)
  uWord_Type m_uWBackUpCaptureMode;				//撮影モードのバックアップ(変化チェック用)
  uWord_Type m_uWBackUpCaptureTrigger;			//キャプチャ動作トリガのバックアップ(変化チェック用)
  struct tm	m_stBackUpFileCreateTime;			//画像ファイル生成時の時間(変化チェック用)
  uWord_Type m_uWFileBranchNum;					//ファイル名の枝番
  uWord_Type m_uWResetCnt;						//リセット時のRetryカウント
  uWord_Type m_uWReqReset;						//リセット要求を保持
  Bool_Type m_blErrSts;							//エラー状態が確定したかを保持
};

//add
//Error状態からActivateへ遷移させる為のクラス
class activator
{
  RTC::UniqueId ec_id;
public:
  activator(RTC::UniqueId _ec_id) : ec_id(_ec_id) {}
  void operator()(RTObject_impl* comp)
  {
	Sleep(100);
    comp->activate(ec_id);
  }
};


extern "C"
{
  DLL_EXPORT void BirdsEyeComposerInit(RTC::Manager* manager);
};

#endif // BIRDSEYECOMPOSER_H
